SystemOrganization addCategory: #DomBuilder!

!Character methodsFor: '*dombuilder' stamp: 'avi 11/16/2005 12:15'!
isXMLSafe
	^ value > 32 or: [#(9 10 13 32) includes: value]! !

TestCase subclass: #DomBuilderTest
	instanceVariableNames: 'builder'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DomBuilder'!

!DomBuilderTest methodsFor: 'setup' stamp: 'jf 9/15/2005 14:59'!
assertText: aString
	| document |
	document _ XMLDOMParser parseDocumentFrom: ('<?xml  version="1.0" encoding="UTF-8" ?>', aString) readStream.
	self assert: document asString = builder document asString! !

!DomBuilderTest methodsFor: 'setup' stamp: 'jf 9/15/2005 17:51'!
expectedFailures
	"testContent fails because YAXO incorrectly stores string and element nodes in separate colelctions.  This means they aren't correctly interleaved.  See comment in DomBuilder>>content:"
	^ #(testContent)! !

!DomBuilderTest methodsFor: 'setup' stamp: 'jf 1/16/2004 21:09'!
setUp
	builder _ DomBuilder new! !

!DomBuilderTest methodsFor: 'tests' stamp: 'jf 1/16/2004 21:23'!
testAttribution
	
	builder element: 'foo' attributes: {'x'->'y'} do: [
		builder element: 'bar' attributes: {'1'->'2'. '2'->'4'}.
	].
	self assertText: '<foo x="y"><bar 1="2" 2="4"/></foo>'
		! !

!DomBuilderTest methodsFor: 'tests' stamp: 'jf 1/16/2004 21:20'!
testComplexNestedElements
	builder element: 'foo' do: [
		builder element: 'bar'.
		builder element: 'baz' do: [
			builder element: 'tiddlywinks'.
		].
		builder element: 'whatever'.
	].
	self assertText: '<foo><bar/><baz><tiddlywinks/></baz><whatever/></foo>'
		! !

!DomBuilderTest methodsFor: 'tests' stamp: 'jf 1/16/2004 21:27'!
testContent
	
	builder element: 'foo' do: [
		builder content: 'this'.
		builder element: 'is'.
		builder content: 'a test'.
	].
	self assertText: '<foo>this<is/>a test</foo>'
		! !

!DomBuilderTest methodsFor: 'tests' stamp: 'jf 1/16/2004 21:14'!
testNestedElements
	builder element: 'foo' do: [
		builder element: 'bar'.
	].
	self assertText: '<foo><bar/></foo>'
		! !

!DomBuilderTest methodsFor: 'tests' stamp: 'jf 1/16/2004 21:08'!
testSimpleElement
	builder element: 'foo'.
	self assertText: '<foo/>'
		! !

Object subclass: #DomBuilder
	instanceVariableNames: 'stack'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DomBuilder'!

!DomBuilder class methodsFor: 'as yet unclassified' stamp: 'jf 1/16/2004 21:11'!
new
	^ self basicNew initialize! !

!DomBuilder methodsFor: 'as yet unclassified' stamp: 'ac 3/9/2006 22:13'!
content: aString
	self flag: #hack.
	"XMLDomParser uses #addContent: to add string nodes and this seems to be what XMLElement expects.  Unfortunately, this results in strings and element nodes not being correct interleaved.  Using #addElement here provides us with correct output as long as certain interfaces of XMLElement like #contentString are not used.  This seemed like a better trade-off for now."
	aString ifNotNil: [stack last addElement: (XMLStringNode string: aString asString xmlSafe)].! !

!DomBuilder methodsFor: 'as yet unclassified' stamp: 'jf 1/16/2004 21:18'!
document
	^ stack first! !

!DomBuilder methodsFor: 'as yet unclassified' stamp: 'jf 1/16/2004 21:26'!
element: aString
	^ self element: aString do: []! !

!DomBuilder methodsFor: 'as yet unclassified' stamp: 'jf 1/16/2004 21:26'!
element: aString attributes: assocCollection
	^ self element: aString attributes: assocCollection do: []! !

!DomBuilder methodsFor: 'as yet unclassified' stamp: 'jf 1/16/2004 21:25'!
element: aString attributes: assocCollection do: aBlock
	| element |
	element _
		XMLElement
			named: aString
			attributes: (assocCollection as: Dictionary).
	stack last addElement: element.
	stack addLast: element.
	aBlock value.
	stack removeLast.
	^ element! !

!DomBuilder methodsFor: 'as yet unclassified' stamp: 'jf 1/16/2004 21:26'!
element: aString do: aBlock
	^ self element: aString attributes: #() do: aBlock! !

!DomBuilder methodsFor: 'as yet unclassified' stamp: 'avi 6/12/2005 14:30'!
element: tagString with: contentString
	self element: tagString do: [self content: contentString]! !

!DomBuilder methodsFor: 'as yet unclassified' stamp: 'avi 6/12/2005 17:31'!
initialize
	stack _ OrderedCollection with: (XMLDocument new version: '1.0')! !

!DomBuilder methodsFor: 'as yet unclassified' stamp: 'ac 5/19/2005 22:44'!
prettyPrintedString
	^ String streamContents: [:stream | self document prettyPrintOn: stream]! !

!String methodsFor: '*dombuilder' stamp: 'avi 11/16/2005 12:02'!
xmlSafe
	^ self select: [:ea | ea isXMLSafe]! !
